==> tecfy_core_package-1.1.19.tar.gz: lib/views/account/account.page.dart <==
part of tecfy_core_client_package;

class AccountPage extends StatefulWidget {
  @override
  _AccountPageState createState() => _AccountPageState();
}

class _AccountPageState extends AppState<AccountPage> {
  late User _user;
  String? _password;

  @override
  void initState() {
    _user = LocalConfigService.user!;
    super.initState();
  }

  Future<dynamic> _onSave() async {
    var data = Map<String, String?>();
    data['password'] = _password;
    data['fullName'] = _user.fullName;
    data['email'] = _user.email;
    data['mobile'] = _user.mobile;
    var result = await TecfyBasicApp.apiService.httpPostEx(
        'user/updateMyInfo',
        json
            .encode(data, toEncodable: EntityService.customEncode)
            .replaceAll('\'', '')
            .replaceAll('\"', '\''));
    print(result);
    if (!result.success) {
      result.showMessage(context);
      return;
    }
    // save local
    LocalConfigService.saveUser(_user);
    // show success message
    await AppNavigator.showMessage(
        context, 'Data Saved Successfully!', MessageType.success);
    //exit
    AppNavigator.pop(context, _user);
  }

  @override
  Widget build(BuildContext context) {
    return BasePage(
      context,
      trans('Account Setting'),
      'settings',
      isMobile: LayoutService.isMobile(context),
      appBarActions: <Widget>[
        LayoutService.isMobile(context)
            ? IconButton(
                icon: Icon(Icons.save, color: ThemeService.mainColor),
                //color: ThemeService.secondryColor,
                tooltip: trans('Save'),
                onPressed: () => _onSave())
            : AppButtonIconText(
                icon: Icon(Icons.save, color: ThemeService.textOnMainColor),
                color: ThemeService.secondryColor,
                label: trans('Save'),
                onPressed: _onSave)
      ],
      child: Align(
        alignment: Alignment.topCenter,
        child: Container(
          constraints: BoxConstraints(maxWidth: ThemeService.containerWidth),
          child: ListView(
              padding: EdgeInsets.symmetric(horizontal: 20),
              children: [
                PorpertyComponent(
                  property: PropertyText(
                    dbName: 'fullName',
                    nameAr: 'الاسم',
                    nameEn: 'Name',
                  ),
                  data: {'fullName': _user.fullName},
                  onChange: (v) => _user.fullName = v,
                ),
                PorpertyComponent(
                  property: PropertyText(
                      dbName: 'username',
                      nameAr: 'اسم المستخدم للدخول',
                      nameEn: 'Login Username'),
                  data: {'username': _user.username},
                  readOnly: true,
                  onChange: (v) => _user.username = v,
                ),
                PorpertyComponent(
                  property: PropertyText(
                      isEmail: true,
                      dbName: 'email',
                      nameAr: 'الايميل',
                      nameEn: 'email'),
                  data: {'email': _user.email},
                  onChange: (v) => _user.email = v,
                ),
                PorpertyComponent(
                  property: PropertyText(
                      dbName: 'mobile', nameAr: 'الموبايل', nameEn: 'mobile'),
                  data: {'mobile': _user.mobile},
                  onChange: (v) => _user.mobile = v,
                ),
                PorpertyComponent(
                  property: PropertyText(
                      dbName: 'password',
                      nameAr: 'الرقم السري',
                      nameEn: 'password',
                      isPassword: true),
                  data: {'password': null},
                  onChange: (v) => _password = v,
                ),
              ]),
        ),
      ),
    );
  }
}

==> tecfy_core_package-1.1.36.tar.gz: lib/views/account/account.page.dart <==
part of tecfy_core_client_package;

class AccountPage extends StatefulWidget {
  @override
  _AccountPageState createState() => _AccountPageState();
}

class _AccountPageState extends TecfyState<AccountPage> {
  late User _user;
  String? _password;

  @override
  void initState() {
    _user = LocalConfigService.user!;
    super.initState();
  }

  Future<dynamic> _onSave() async {
    var data = Map<String, String?>();
    data['password'] = _password;
    data['fullName'] = _user.fullName;
    data['email'] = _user.email;
    data['mobile'] = _user.mobile;
    var result = await TecfyBasicApp.apiService.httpPostEx(
        'user/updateMyInfo',
        json
            .encode(data, toEncodable: EntityService.customEncode)
            .replaceAll('\'', '')
            .replaceAll('\"', '\''));
    if (kDebugMode) print(result);
    if (!result.success) {
      result.showMessage(context);
      return;
    }
    // save local
    LocalConfigService.saveUser(_user);
    // show success message
    await AppNavigator.showMessage(
        context, 'Data Saved Successfully!', MessageType.success);
    //exit
    AppNavigator.pop(context, _user);
  }

  @override
  Widget build(BuildContext context) {
    return BasePage(
      context,
      trans('Account Setting'),
      'settings',
      isMobile: LayoutService.isMobile(context),
      appBarActions: <Widget>[
        LayoutService.isMobile(context)
            ? IconButton(
                icon: Icon(Icons.save, color: ThemeService.mainColor),
                //color: ThemeService.secondryColor,
                tooltip: trans('Save'),
                onPressed: () => _onSave())
            : AppButtonIconText(
                icon: Icon(Icons.save, color: ThemeService.textOnMainColor),
                color: ThemeService.secondryColor,
                label: trans('Save'),
                onPressed: _onSave)
      ],
      child: Align(
        alignment: Alignment.topCenter,
        child: Container(
          constraints: BoxConstraints(maxWidth: ThemeService.containerWidth),
          child: ListView(
              padding: EdgeInsets.symmetric(horizontal: 20),
              children: [
                PorpertyComponent(
                  property: PropertyText(
                    dbName: 'fullName',
                    nameAr: 'الاسم',
                    nameEn: 'Name',
                  ),
                  data: {'fullName': _user.fullName},
                  onChange: (v) => _user.fullName = v,
                ),
                PorpertyComponent(
                  property: PropertyText(
                      dbName: 'username',
                      nameAr: 'اسم المستخدم للدخول',
                      nameEn: 'Login Username'),
                  data: {'username': _user.username},
                  readOnly: true,
                  onChange: (v) => _user.username = v,
                ),
                PorpertyComponent(
                  property: PropertyText(
                      isEmail: true,
                      dbName: 'email',
                      nameAr: 'الايميل',
                      nameEn: 'email'),
                  data: {'email': _user.email},
                  onChange: (v) => _user.email = v,
                ),
                PorpertyComponent(
                  property: PropertyText(
                      dbName: 'mobile', nameAr: 'الموبايل', nameEn: 'mobile'),
                  data: {'mobile': _user.mobile},
                  onChange: (v) => _user.mobile = v,
                ),
                PorpertyComponent(
                  property: PropertyText(
                      dbName: 'password',
                      nameAr: 'الرقم السري',
                      nameEn: 'password',
                      isPassword: true),
                  data: {'password': null},
                  onChange: (v) => _password = v,
                ),
              ]),
        ),
      ),
    );
  }
}
